@@ -48,7 +48,7 @@ class DirectusApi:
         response = requests.post(url, json=items, headers=self.request_headers)
         return response
 
-    def updates_items(self, items: list, collection: str) -> Response:
+    def update_items(self, items: list, collection: str) -> Response:
         """
         Update multiple items in a collection. The items must have an id (primary key) field.
         Make a PATCH-Request to /items/<collection_name> and return the response as JSON.
